1. Installation — django-pki v0.20.0 documentation

### Navigation

- index
- next |
- previous |
- django-pki v0.20.0 documentation »

# 1. Installation

## 1.1. Prequisites

- Python (tested on 2.5 and 2.6)
- Django framework (>= 1.2)
- A RDBMS of your choice (MySQL, PostgreSQL, SQLite, Oracle)
- OpenSSL
- Optional jQuery library (djago-pki already shipped with built-in jquery-1.5)
- Graphviz + pygraphviz (Tree viewer and object locator requirement)
- zipfile Python library (Shipped with python)
- south library

## 1.2. pip / easy_install

You can install django-pki via pip or easy_install:

    $ pip install django-pki

or

    $ easy_install django-pki

## 1.3. Sourcecode from GitHub

Clone github repository (every release version is tagged):

    $ git clone git://github.com/dkerwin/django-pki.git

### Navigation

- index
- next |
- previous |
- django-pki v0.20.0 documentation »